;;; FG42Cube --- The meta cube for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2023 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://ziglab.com/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;;; Code:
(require 'fg42/cube)
(require 'fg42/utils)

(require 'cubes/editor)
(require 'cubes/org)
(require 'cubes/elisp)
(require 'cubes/region-expansion)
(require 'cubes/wm)
(require 'cubes/modeline)
(require 'cubes/autocompletion)
(require 'cubes/golang)
(require 'cubes/project)
(require 'cubes/irc)
(require 'cubes/terminal)
(require 'cubes/java)
(require 'cubes/python)
(require 'cubes/cpp)
(require 'cubes/snippets)
(require 'cubes/rust)
(require 'cubes/mastodon)
(require 'cubes/git)
(require 'cubes/bookmark)
(require 'cubes/terraform)
(require 'cubes/graph)
(require 'cubes/clojure)
(require 'cubes/scheme)
(require 'cubes/meson)
(require 'cubes/godot3d)
(require 'cubes/meissa)
(require 'cubes/proof)
(require 'cubes/agda)
(require 'cubes/notifications)
(require 'cubes/noether)
(require 'cubes/nix)
(require 'cubes/julia)


(defcube fg42/editor
  "A meta cube that contains all the cubes in the system. Calling
This cube is enough to load everything and control what cube to execute
via flags."
  :title "Editor cube"
  :flag-default t
  :flag fg42-editor-cube
  :init-hook (lambda (params)
               (mapc
                (lambda (cube)
                  (when (not (string= (symbol-name cube)
                                      "fg42/editor"))
                    (let ((cube-params (plist-get
                                        params
                                        (intern (concat ":" (symbol-name cube))))))
                      (eval `(funcall #',cube ,@cube-params)))))
                fg42/available-cubes)))



(provide 'cubes/fg42)
;;; fg42.el ends here
