;;; JavaCubes --- The Java cubes for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2023 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;;; Code:
(require 'fpkg)
(require 'fg42/cube)


(defcube fg42/gradle-cube
  "Gradle support"
  :title "Gradle Cube"
  :flag gradle
  :flag-default t

  (fpkg/use groovy-mode
    :mode "\\.gradle\\'")

  (fpkg/use gradle-mode
    :hook (java-mode-hook . gradle-mode))

  (when-flag flycheck
    (fpkg/use flycheck-gradle)))


(defcube fg42/java-cube
  "Java cube"
  :title "Java Cube"
  :flag java
  :flag-default t

  (add-hook 'java-mode-hook
            (lambda()
              ;; To fix the indentation of function arguments
              (c-set-offset 'arglist-intro '+)
              (setq java-basic-offset 2)
              (setq c-basic-offset 2)
              (when-flag lsp-java
                (setq lsp-java-server-install-dir fg42-tmp)
                (lsp))))

  (when-flag gradle
    (fg42/gradle-cube))

  (when-flag lsp
    (fpkg/use lsp-java)))



(provide 'cubes/java)
;;; java.el ends here
