;;; Themes --- Theme library of FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2023 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://devheroes.codes/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;; Cubes are the building blocks of any `FG42' editor.  Each `cube' is a
;; unit which defines different abilities in a deterministic and idempotent
;; way.  Cubes are composable and a composition of cubes creates an editor.
;;
;;; Code:
(require 'fg42/utils)

(defvar fg42/ui-hook ()
  "A hook that cubes can use via :ui-hook property.
It executes way before the rest of the cubes.")

(defvar fg42/before-initializing-theme-hook ()
  "The hook to plug any configuration to before initialize event of themes.")

(defvar fg42/after-initializing-theme-hook ()
  "The hook to plug any configuration to after initialize event of themes.")


(defmacro fg42/setup-theme (&rest body)
  "Run the BODY inside the FG42 theme setup context."
  `(progn
     ;; TODO: This is a bad practice. Find a better solution
     (run-hooks 'fg42/before-initializing-theme-hook)
     ,@body))


(provide 'fg42/themes)
;;; themes.el ends here
